@@ -345,7 +345,8 @@ class fMMS_SenderUI(hildon.Program):
 		except Exception, exc:
 			log.exception("Sender failed.")
 			note = osso.SystemNote(self.osso_c)
-			note.system_note_dialog("Sending failed:\nGeneral error, please contact the author." , 'notice')
+			errmsg = "%s" % exc
+			note.system_note_dialog("Sending failed:\n%s" % errmsg, 'notice')
 			#raise
 		finally:
 			hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
